import models
from datetime import datetime
from os import path
from sqlalchemy import create_engine, or_, insert, Table, Column, Integer, String, ForeignKey, DateTime
from sqlalchemy.orm import declarative_base, Session

class DatabaseConnector:
    def __init__(self, data_path):
        self.engine = create_engine("sqlite+pysqlite:///%s" % path.join(data_path, "overseer.sqlite"), echo=True, future=True)
        models.Base.metadata.create_all(self.engine)

    def create_scan_result(self, ip_address, scan_results, hostname=None):
        session = Session(bind=self.engine)

        # Does an existing target exist?
        scan_target = session.query(models.ScanTarget).filter(or_(
            models.ScanTarget.ip==ip_address,
            models.ScanTarget.hostname==hostname,
        )).first()

        # Nope, create one
        if not scan_target:
            scan_target = models.ScanTarget(ip=ip_address, hostname=hostname)
            session.add(scan_target)
            session.commit()

        # Create scan history
        scan_history = models.ScanHistory(target=scan_target.id, results=",".join(map(str, scan_results)), datetime=datetime.now())
        session.add(scan_history)
        session.commit()

        session.close()


    def create_target(self, ip_address, hostname):
        stmt = insert(models.ScanTarget).values(ip=ip_address, hostname=hostname)
        compiled = stmt.compile()
        self.__execute_statement(stmt)
        return stmt


    def __execute_statement(self, stmt):
        with self.engine.connect() as conn:
            result = conn.execute(stmt)
            conn.commit()
            return result


# FOR TESTING PURPOSES
def main():
    db = DatabaseConnector("/Users/evanreichard/Development/git/overseer/src/overseer")
    db.create_scan_result(1234577, [5,6,7,8], "test222.com")
if __name__ == "__main__":
    main()
